# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlInsightAggregationCollection(object):
    """
    SQL Insights response.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlInsightAggregationCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_interval_start:
            The value to assign to the time_interval_start property of this SqlInsightAggregationCollection.
        :type time_interval_start: datetime

        :param time_interval_end:
            The value to assign to the time_interval_end property of this SqlInsightAggregationCollection.
        :type time_interval_end: datetime

        :param inventory:
            The value to assign to the inventory property of this SqlInsightAggregationCollection.
        :type inventory: oci.opsi.models.SqlInventory

        :param items:
            The value to assign to the items property of this SqlInsightAggregationCollection.
        :type items: list[oci.opsi.models.SqlInsightAggregation]

        :param thresholds:
            The value to assign to the thresholds property of this SqlInsightAggregationCollection.
        :type thresholds: oci.opsi.models.SqlInsightThresholds

        """
        self.swagger_types = {
            'time_interval_start': 'datetime',
            'time_interval_end': 'datetime',
            'inventory': 'SqlInventory',
            'items': 'list[SqlInsightAggregation]',
            'thresholds': 'SqlInsightThresholds'
        }

        self.attribute_map = {
            'time_interval_start': 'timeIntervalStart',
            'time_interval_end': 'timeIntervalEnd',
            'inventory': 'inventory',
            'items': 'items',
            'thresholds': 'thresholds'
        }

        self._time_interval_start = None
        self._time_interval_end = None
        self._inventory = None
        self._items = None
        self._thresholds = None

    @property
    def time_interval_start(self):
        """
        **[Required]** Gets the time_interval_start of this SqlInsightAggregationCollection.
        The start timestamp that was passed into the request.


        :return: The time_interval_start of this SqlInsightAggregationCollection.
        :rtype: datetime
        """
        return self._time_interval_start

    @time_interval_start.setter
    def time_interval_start(self, time_interval_start):
        """
        Sets the time_interval_start of this SqlInsightAggregationCollection.
        The start timestamp that was passed into the request.


        :param time_interval_start: The time_interval_start of this SqlInsightAggregationCollection.
        :type: datetime
        """
        self._time_interval_start = time_interval_start

    @property
    def time_interval_end(self):
        """
        **[Required]** Gets the time_interval_end of this SqlInsightAggregationCollection.
        The end timestamp that was passed into the request.


        :return: The time_interval_end of this SqlInsightAggregationCollection.
        :rtype: datetime
        """
        return self._time_interval_end

    @time_interval_end.setter
    def time_interval_end(self, time_interval_end):
        """
        Sets the time_interval_end of this SqlInsightAggregationCollection.
        The end timestamp that was passed into the request.


        :param time_interval_end: The time_interval_end of this SqlInsightAggregationCollection.
        :type: datetime
        """
        self._time_interval_end = time_interval_end

    @property
    def inventory(self):
        """
        **[Required]** Gets the inventory of this SqlInsightAggregationCollection.

        :return: The inventory of this SqlInsightAggregationCollection.
        :rtype: oci.opsi.models.SqlInventory
        """
        return self._inventory

    @inventory.setter
    def inventory(self, inventory):
        """
        Sets the inventory of this SqlInsightAggregationCollection.

        :param inventory: The inventory of this SqlInsightAggregationCollection.
        :type: oci.opsi.models.SqlInventory
        """
        self._inventory = inventory

    @property
    def items(self):
        """
        **[Required]** Gets the items of this SqlInsightAggregationCollection.
        List of insights.


        :return: The items of this SqlInsightAggregationCollection.
        :rtype: list[oci.opsi.models.SqlInsightAggregation]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this SqlInsightAggregationCollection.
        List of insights.


        :param items: The items of this SqlInsightAggregationCollection.
        :type: list[oci.opsi.models.SqlInsightAggregation]
        """
        self._items = items

    @property
    def thresholds(self):
        """
        **[Required]** Gets the thresholds of this SqlInsightAggregationCollection.

        :return: The thresholds of this SqlInsightAggregationCollection.
        :rtype: oci.opsi.models.SqlInsightThresholds
        """
        return self._thresholds

    @thresholds.setter
    def thresholds(self, thresholds):
        """
        Sets the thresholds of this SqlInsightAggregationCollection.

        :param thresholds: The thresholds of this SqlInsightAggregationCollection.
        :type: oci.opsi.models.SqlInsightThresholds
        """
        self._thresholds = thresholds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

import base64
import datetime
import json
import os
import os.path

import pytz

from oci._vendor import six
from oci.exceptions import InvalidConfig

try:
    from urllib.parse import urlparse
except ImportError:
    from urlparse import urlparse

from io import SEEK_SET
import logging

logger = logging.getLogger(__name__)
logger = logging.getLogger(__name__)
INSTANCE_PRINCIPAL_AUTHENTICATION_TYPE_VALUE_NAME = 'instance_principal'
DELEGATION_TOKEN_WITH_INSTANCE_PRINCIPAL_AUTHENTICATION_TYPE = 'delegation_token_with_instance_principal'
RESOURCE_PRINCIPAL_AUTHENTICATION_TYPE = 'resource_principal'
DELEGATION_TOKEN_FILE_FIELD_NAME = 'delegation_token_file'
AUTHENTICATION_TYPE_FIELD_NAME = 'authentication_type'
MEBIBYTE = 1024 * 1024
DEFAULT_BUFFER_SIZE = 100 * MEBIBYTE
DEFAULT_PART_SIZE = 128 * MEBIBYTE

try:
    # PY3+
    import collections.abc as abc
except ImportError:
    # PY2
    import collections as abc

missing_attr = object()


def to_dict(obj):
    """Helper to flatten models into dicts for rendering.

    The following conversions are applied:

    * datetime.date, datetime.datetime, datetime.time
      are converted into ISO8601 UTC strings
    """
    # Shortcut strings so they don't count as Iterables
    if isinstance(obj, six.string_types):
        return obj
    elif obj is NONE_SENTINEL:
        return None
    elif isinstance(obj, (datetime.datetime, datetime.time)):
        # always use UTC
        if not obj.tzinfo:
            obj = pytz.utc.localize(obj)
        if isinstance(obj, datetime.datetime):
            # only datetime.datetime takes a separator
            return obj.isoformat(sep="T")
        return obj.isoformat()
    elif isinstance(obj, datetime.date):
        # datetime.date doesn't have a timezone
        return obj.isoformat()
    elif isinstance(obj, abc.Mapping):
        return {k: to_dict(v) for k, v in six.iteritems(obj)}
    elif isinstance(obj, abc.Iterable):
        return [to_dict(v) for v in obj]
    # Not a string, datetime, dict, list, or model - return directly
    elif not hasattr(obj, "swagger_types"):
        return obj

    # Collect attrs from obj according to swagger_types into a dict
    as_dict = {}
    for key in six.iterkeys(obj.swagger_types):
        value = getattr(obj, key, missing_attr)
        if value is not missing_attr:
            as_dict[key] = to_dict(value)
    return as_dict


def formatted_flat_dict(model):
    """Returns a string of the model flattened as a dict, sorted"""
    as_dict = to_dict(model)
    return json.dumps(
        as_dict,
        indent=2,
        sort_keys=True
    )


def value_allowed_none_or_none_sentinel(value_to_test, allowed_values):
    return value_to_test is None or value_to_test is NONE_SENTINEL or value_to_test in allowed_values


def file_content_as_launch_instance_user_data(file_path):
    """
    Takes a file path and returns a Base64-encoded string which can be provided as the value of the ``user_data`` key
    in the ``metadata`` dictionary when launching an instance(see :py:class:`~oci.core.models.LaunchInstanceDetails`
    for more information).

    :param str file_path:
      The path to the file whose contents will be Base64-encoded

    :return: The Base64-encoded string
    :rtype: str
    """

    full_path = os.path.expandvars(os.path.expanduser(file_path))
    with open(full_path, 'rb') as f:
        file_contents = f.read()

    return base64.b64encode(file_contents).decode('utf-8')


class Sentinel(object):
    """Named singletons for clear docstrings.
    Also used to differentiate an explicit param of None from a lack of argument.

    .. code-block:: pycon

        >>> missing = Sentinel("Missing", False)
        >>> also_missing = Sentinel("Missing", False)
        >>> assert missing is also_missing
        >>> repr(missing)
        <Missing>
        >>> assert bool(missing) is False
    """
    _symbols = {}

    def __new__(cls, name, truthy=True):
        sentinel = Sentinel._symbols.get(name, None)
        if sentinel is None:
            sentinel = Sentinel._symbols[name] = super(Sentinel, cls).__new__(cls)
        elif sentinel.truthy is not truthy:
            raise ValueError("Tried to get existing Sentinel {!r} with wrong truthy value".format(sentinel))
        return sentinel

    def __init__(self, name, truthy=True):
        self.name = name
        self.truthy = truthy

    def __repr__(self):
        # Sentinel("Missing") -> <Missing>
        return "<{}>".format(self.name)

    def __bool__(self):
        return self.truthy
    # PY2 Compatibility
    __nonzero__ = __bool__


NONE_SENTINEL = Sentinel(name='None', truthy=False)

WAIT_RESOURCE_NOT_FOUND = Sentinel(name='WaitResourceNotFound', truthy=False)


def _get_signer_from_delegation_token_instance_principal(config):
    # Import the signer inside the function to avoid circular imports during initialization
    from oci.auth.signers import InstancePrincipalsDelegationTokenSigner

    signer_kwargs = {}

    delegation_token_file_path = config.get(DELEGATION_TOKEN_FILE_FIELD_NAME)

    if delegation_token_file_path is None:
        raise InvalidConfig('ERROR: {} was not provided.'.format(DELEGATION_TOKEN_FILE_FIELD_NAME))

    expanded_delegation_token_file_path = os.path.expanduser(delegation_token_file_path)
    if not os.path.isfile(expanded_delegation_token_file_path):
        raise InvalidConfig('ERROR: delegation token file not found at {}'.format(expanded_delegation_token_file_path))

    with open(expanded_delegation_token_file_path, mode="r") as f:
        delegation_token = f.read().strip()
    if delegation_token is None:
        raise InvalidConfig('ERROR: delegation_token was not provided.')
    signer_kwargs['delegation_token'] = delegation_token
    # Return signer with delegation token
    return InstancePrincipalsDelegationTokenSigner(**signer_kwargs)


def _get_signer_from_resource_principal(config):
    # Import the signer inside the function to avoid circular imports during initialization
    from oci.auth.signers import get_resource_principal_signer

    return get_resource_principal_signer()


# This map can be easily extended to accommodate support for more auth types through the config file
AUTH_TYPE_TO_SIGNER_FUNCTION_MAP = {
    DELEGATION_TOKEN_WITH_INSTANCE_PRINCIPAL_AUTHENTICATION_TYPE: _get_signer_from_delegation_token_instance_principal,
    RESOURCE_PRINCIPAL_AUTHENTICATION_TYPE: _get_signer_from_resource_principal,
}


def get_signer_from_authentication_type(config):
    # This is currently made for allowing SDK to run seamlessly on cloud shell
    auth_type = get_authentication_type_from_config(config)

    # Get the signer function from map
    signer_function = AUTH_TYPE_TO_SIGNER_FUNCTION_MAP.get(auth_type)
    return signer_function(config)


def get_authentication_type_from_config(config):
    auth_type = config.get(AUTHENTICATION_TYPE_FIELD_NAME)
    if auth_type is None:
        raise ValueError("{} not provided".format(AUTHENTICATION_TYPE_FIELD_NAME))

    # Currently the SDK supports only the cloud shell use case, this can be extended for other auth types
    if auth_type == INSTANCE_PRINCIPAL_AUTHENTICATION_TYPE_VALUE_NAME:
        if DELEGATION_TOKEN_FILE_FIELD_NAME in config:
            return DELEGATION_TOKEN_WITH_INSTANCE_PRINCIPAL_AUTHENTICATION_TYPE
        else:
            raise InvalidConfig("The authentication type {} requires config values for the keys {}".format(DELEGATION_TOKEN_WITH_INSTANCE_PRINCIPAL_AUTHENTICATION_TYPE, DELEGATION_TOKEN_FILE_FIELD_NAME))
    else:
        raise InvalidConfig("The authentication type {} is not supported".format(auth_type))


def back_up_body_calculate_stream_content_length(stream, buffer_limit=DEFAULT_BUFFER_SIZE):
    # Note: Need to read in chunks, older version of Python will fail to read more than 2GB at once.
    # We pull data in chunks (128MB at a time) from the stream until there is no more
    logger.warning("Reading the stream to calculate its content-length. Process may freeze for very big streams. Consider passing in content length for big objects")
    try:
        keep_reading = True
        part_size = DEFAULT_PART_SIZE
        content_length = 0
        content = ""
        byte_content = b''
        while keep_reading:
            if hasattr(stream, 'buffer'):
                content = stream.buffer.read(part_size)
            elif hasattr(stream, 'read'):
                content = stream.read(part_size)
            else:
                raise TypeError("Stream object does not contain a 'read' property. Cannot auto calculate content length, please pass in content length")
            if len(content) == 0:
                keep_reading = False
            byte_content += content
            content_length += len(content)
            if (buffer_limit and content_length > buffer_limit):
                raise BufferError("Stream size is greater than the buffer_limit, please pass in a bigger buffer_limit or pass in content length to the request")
        return {"content_length": content_length, "byte_content": byte_content}
    except(IOError, OSError):
        raise TypeError("Stream object's content length cannot be calculated, please pass in content length")


# This helper function checks if an object can have it's content length auto-calculated by the Request library
def is_content_length_calculable_by_req_util(o):
    if hasattr(o, '__len__') or hasattr(o, 'len') or hasattr(o, 'fileno') or hasattr(o, 'tell'):
        return True
    logger.warning("Request did not contain content-length and stream object does not contain fileno or tell property. Stream object will be read to calculate content-length")
    return False


def extract_service_endpoint(endpoint_with_base_path):
    """
    Takes a Service Endpoint with base-path embedded and extracts the Service Endpoint from it.

    :param str endpoint_with_base_path:
    Service Endpoint with base-path embedded

    :return: The Service Endpoint without base-path.
    :rtype: str
    """
    parsed_endpoint = urlparse(endpoint_with_base_path)
    return parsed_endpoint.scheme + r'://' + parsed_endpoint.netloc


def should_record_body_position_for_retry(func_ref, **func_kwargs):
    func_name = func_ref.__name__
    # TODO: remove Python 2 requirements, use qualname
    if func_name == 'call_api':
        body = func_kwargs.get('body')
        # A file-like object body should be treated differently for retry
        if body and hasattr(body, 'read'):
            return True
        return False
    return False


def record_body_position_for_rewind(body):
    is_body_rewindable = True
    if getattr(body, 'tell', None) is not None:
        try:
            # Attempt to record current body position
            body_position = body.tell()
        except (IOError, OSError):
            # If we cannot record the current body position for a file-like body, then we should not retry
            is_body_rewindable = False
            body_position = None
            logger.warning("Unable to record body position for rewinding. This request will not be retried/rewound")
    else:
        # If the body does not support tell, then don't retry
        is_body_rewindable = False
        body_position = None
        logger.warning("Unable to record body position for rewinding. This request will not be retried/rewound")
    return is_body_rewindable, body_position


def rewind_body(body, body_position):
    if getattr(body, 'seek', None) is not None:
        try:
            body.seek(body_position, SEEK_SET)
        except (IOError, OSError):
            # If we're unable to reset the body position, then we should not retry
            logger.warning("Unable to reset body position for rewinding. This request will not be retried/rewound")
            return False
        return True
    # if the body does not support seek, then we should not retry
    logger.warning("Unable to reset body position for rewinding. This request will not be retried/rewound")
    return False


def read_stream_for_signing(signing_algorithm, body):
    bytes_read = 0
    try:
        while True:
            chunk = ""
            if hasattr(body, "read"):
                chunk = body.read(DEFAULT_PART_SIZE)
            elif hasattr(body, "buffer"):
                chunk = body.buffer.read(DEFAULT_PART_SIZE)
            if len(chunk) == 0:
                break
            bytes_read += len(chunk)
            signing_algorithm.update(chunk)
    except(IOError, OSError):
        logger.warning("Unable to read stream body for signing")
        bytes_read = -1
    return bytes_read



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TargetTag(object):
    """
    A target tag with tag namespace, tag definition, tag value type, and tag values attached to the current profile override.
    """

    #: A constant which can be used with the tag_value_type property of a TargetTag.
    #: This constant has a value of "VALUE"
    TAG_VALUE_TYPE_VALUE = "VALUE"

    #: A constant which can be used with the tag_value_type property of a TargetTag.
    #: This constant has a value of "ANY"
    TAG_VALUE_TYPE_ANY = "ANY"

    def __init__(self, **kwargs):
        """
        Initializes a new TargetTag object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tag_namespace_name:
            The value to assign to the tag_namespace_name property of this TargetTag.
        :type tag_namespace_name: str

        :param tag_definition_name:
            The value to assign to the tag_definition_name property of this TargetTag.
        :type tag_definition_name: str

        :param tag_value_type:
            The value to assign to the tag_value_type property of this TargetTag.
            Allowed values for this property are: "VALUE", "ANY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type tag_value_type: str

        :param tag_values:
            The value to assign to the tag_values property of this TargetTag.
        :type tag_values: list[str]

        """
        self.swagger_types = {
            'tag_namespace_name': 'str',
            'tag_definition_name': 'str',
            'tag_value_type': 'str',
            'tag_values': 'list[str]'
        }

        self.attribute_map = {
            'tag_namespace_name': 'tagNamespaceName',
            'tag_definition_name': 'tagDefinitionName',
            'tag_value_type': 'tagValueType',
            'tag_values': 'tagValues'
        }

        self._tag_namespace_name = None
        self._tag_definition_name = None
        self._tag_value_type = None
        self._tag_values = None

    @property
    def tag_namespace_name(self):
        """
        **[Required]** Gets the tag_namespace_name of this TargetTag.
        The name of the tag namespace.


        :return: The tag_namespace_name of this TargetTag.
        :rtype: str
        """
        return self._tag_namespace_name

    @tag_namespace_name.setter
    def tag_namespace_name(self, tag_namespace_name):
        """
        Sets the tag_namespace_name of this TargetTag.
        The name of the tag namespace.


        :param tag_namespace_name: The tag_namespace_name of this TargetTag.
        :type: str
        """
        self._tag_namespace_name = tag_namespace_name

    @property
    def tag_definition_name(self):
        """
        **[Required]** Gets the tag_definition_name of this TargetTag.
        The name of the tag definition.


        :return: The tag_definition_name of this TargetTag.
        :rtype: str
        """
        return self._tag_definition_name

    @tag_definition_name.setter
    def tag_definition_name(self, tag_definition_name):
        """
        Sets the tag_definition_name of this TargetTag.
        The name of the tag definition.


        :param tag_definition_name: The tag_definition_name of this TargetTag.
        :type: str
        """
        self._tag_definition_name = tag_definition_name

    @property
    def tag_value_type(self):
        """
        **[Required]** Gets the tag_value_type of this TargetTag.
        The tag value type.

        Allowed values for this property are: "VALUE", "ANY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The tag_value_type of this TargetTag.
        :rtype: str
        """
        return self._tag_value_type

    @tag_value_type.setter
    def tag_value_type(self, tag_value_type):
        """
        Sets the tag_value_type of this TargetTag.
        The tag value type.


        :param tag_value_type: The tag_value_type of this TargetTag.
        :type: str
        """
        allowed_values = ["VALUE", "ANY"]
        if not value_allowed_none_or_none_sentinel(tag_value_type, allowed_values):
            tag_value_type = 'UNKNOWN_ENUM_VALUE'
        self._tag_value_type = tag_value_type

    @property
    def tag_values(self):
        """
        Gets the tag_values of this TargetTag.
        The list of tag values.


        :return: The tag_values of this TargetTag.
        :rtype: list[str]
        """
        return self._tag_values

    @tag_values.setter
    def tag_values(self, tag_values):
        """
        Sets the tag_values of this TargetTag.
        The list of tag values.


        :param tag_values: The tag_values of this TargetTag.
        :type: list[str]
        """
        self._tag_values = tag_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectSummary(object):
    """
    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized,
    talk to an administrator. If you are an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the storage_tier property of a ObjectSummary.
    #: This constant has a value of "Standard"
    STORAGE_TIER_STANDARD = "Standard"

    #: A constant which can be used with the storage_tier property of a ObjectSummary.
    #: This constant has a value of "InfrequentAccess"
    STORAGE_TIER_INFREQUENT_ACCESS = "InfrequentAccess"

    #: A constant which can be used with the storage_tier property of a ObjectSummary.
    #: This constant has a value of "Archive"
    STORAGE_TIER_ARCHIVE = "Archive"

    #: A constant which can be used with the archival_state property of a ObjectSummary.
    #: This constant has a value of "Archived"
    ARCHIVAL_STATE_ARCHIVED = "Archived"

    #: A constant which can be used with the archival_state property of a ObjectSummary.
    #: This constant has a value of "Restoring"
    ARCHIVAL_STATE_RESTORING = "Restoring"

    #: A constant which can be used with the archival_state property of a ObjectSummary.
    #: This constant has a value of "Restored"
    ARCHIVAL_STATE_RESTORED = "Restored"

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ObjectSummary.
        :type name: str

        :param size:
            The value to assign to the size property of this ObjectSummary.
        :type size: int

        :param md5:
            The value to assign to the md5 property of this ObjectSummary.
        :type md5: str

        :param time_created:
            The value to assign to the time_created property of this ObjectSummary.
        :type time_created: datetime

        :param etag:
            The value to assign to the etag property of this ObjectSummary.
        :type etag: str

        :param storage_tier:
            The value to assign to the storage_tier property of this ObjectSummary.
            Allowed values for this property are: "Standard", "InfrequentAccess", "Archive", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type storage_tier: str

        :param archival_state:
            The value to assign to the archival_state property of this ObjectSummary.
            Allowed values for this property are: "Archived", "Restoring", "Restored", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type archival_state: str

        :param time_modified:
            The value to assign to the time_modified property of this ObjectSummary.
        :type time_modified: datetime

        """
        self.swagger_types = {
            'name': 'str',
            'size': 'int',
            'md5': 'str',
            'time_created': 'datetime',
            'etag': 'str',
            'storage_tier': 'str',
            'archival_state': 'str',
            'time_modified': 'datetime'
        }

        self.attribute_map = {
            'name': 'name',
            'size': 'size',
            'md5': 'md5',
            'time_created': 'timeCreated',
            'etag': 'etag',
            'storage_tier': 'storageTier',
            'archival_state': 'archivalState',
            'time_modified': 'timeModified'
        }

        self._name = None
        self._size = None
        self._md5 = None
        self._time_created = None
        self._etag = None
        self._storage_tier = None
        self._archival_state = None
        self._time_modified = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ObjectSummary.
        The name of the object. Avoid entering confidential information.
        Example: test/object1.log


        :return: The name of this ObjectSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ObjectSummary.
        The name of the object. Avoid entering confidential information.
        Example: test/object1.log


        :param name: The name of this ObjectSummary.
        :type: str
        """
        self._name = name

    @property
    def size(self):
        """
        Gets the size of this ObjectSummary.
        Size of the object in bytes.


        :return: The size of this ObjectSummary.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this ObjectSummary.
        Size of the object in bytes.


        :param size: The size of this ObjectSummary.
        :type: int
        """
        self._size = size

    @property
    def md5(self):
        """
        Gets the md5 of this ObjectSummary.
        Base64-encoded MD5 hash of the object data.


        :return: The md5 of this ObjectSummary.
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """
        Sets the md5 of this ObjectSummary.
        Base64-encoded MD5 hash of the object data.


        :param md5: The md5 of this ObjectSummary.
        :type: str
        """
        self._md5 = md5

    @property
    def time_created(self):
        """
        Gets the time_created of this ObjectSummary.
        The date and time the object was created, as described in `RFC 2616`__.

        __ https://tools.ietf.org/html/rfc2616#section-14.29


        :return: The time_created of this ObjectSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ObjectSummary.
        The date and time the object was created, as described in `RFC 2616`__.

        __ https://tools.ietf.org/html/rfc2616#section-14.29


        :param time_created: The time_created of this ObjectSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def etag(self):
        """
        Gets the etag of this ObjectSummary.
        The current entity tag (ETag) for the object.


        :return: The etag of this ObjectSummary.
        :rtype: str
        """
        return self._etag

    @etag.setter
    def etag(self, etag):
        """
        Sets the etag of this ObjectSummary.
        The current entity tag (ETag) for the object.


        :param etag: The etag of this ObjectSummary.
        :type: str
        """
        self._etag = etag

    @property
    def storage_tier(self):
        """
        Gets the storage_tier of this ObjectSummary.
        The storage tier that the object is stored in.

        Allowed values for this property are: "Standard", "InfrequentAccess", "Archive", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The storage_tier of this ObjectSummary.
        :rtype: str
        """
        return self._storage_tier

    @storage_tier.setter
    def storage_tier(self, storage_tier):
        """
        Sets the storage_tier of this ObjectSummary.
        The storage tier that the object is stored in.


        :param storage_tier: The storage_tier of this ObjectSummary.
        :type: str
        """
        allowed_values = ["Standard", "InfrequentAccess", "Archive"]
        if not value_allowed_none_or_none_sentinel(storage_tier, allowed_values):
            storage_tier = 'UNKNOWN_ENUM_VALUE'
        self._storage_tier = storage_tier

    @property
    def archival_state(self):
        """
        Gets the archival_state of this ObjectSummary.
        Archival state of an object. This field is set only for objects in Archive tier.

        Allowed values for this property are: "Archived", "Restoring", "Restored", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The archival_state of this ObjectSummary.
        :rtype: str
        """
        return self._archival_state

    @archival_state.setter
    def archival_state(self, archival_state):
        """
        Sets the archival_state of this ObjectSummary.
        Archival state of an object. This field is set only for objects in Archive tier.


        :param archival_state: The archival_state of this ObjectSummary.
        :type: str
        """
        allowed_values = ["Archived", "Restoring", "Restored"]
        if not value_allowed_none_or_none_sentinel(archival_state, allowed_values):
            archival_state = 'UNKNOWN_ENUM_VALUE'
        self._archival_state = archival_state

    @property
    def time_modified(self):
        """
        Gets the time_modified of this ObjectSummary.
        The date and time the object was modified, as described in `RFC 2616`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc2616


        :return: The time_modified of this ObjectSummary.
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """
        Sets the time_modified of this ObjectSummary.
        The date and time the object was modified, as described in `RFC 2616`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc2616


        :param time_modified: The time_modified of this ObjectSummary.
        :type: datetime
        """
        self._time_modified = time_modified

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataPumpSettings(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Optional settings for Data Pump Export and Import jobs
    """

    #: A constant which can be used with the job_mode property of a DataPumpSettings.
    #: This constant has a value of "FULL"
    JOB_MODE_FULL = "FULL"

    #: A constant which can be used with the job_mode property of a DataPumpSettings.
    #: This constant has a value of "SCHEMA"
    JOB_MODE_SCHEMA = "SCHEMA"

    #: A constant which can be used with the job_mode property of a DataPumpSettings.
    #: This constant has a value of "TABLE"
    JOB_MODE_TABLE = "TABLE"

    #: A constant which can be used with the job_mode property of a DataPumpSettings.
    #: This constant has a value of "TABLESPACE"
    JOB_MODE_TABLESPACE = "TABLESPACE"

    #: A constant which can be used with the job_mode property of a DataPumpSettings.
    #: This constant has a value of "TRANSPORTABLE"
    JOB_MODE_TRANSPORTABLE = "TRANSPORTABLE"

    def __init__(self, **kwargs):
        """
        Initializes a new DataPumpSettings object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param job_mode:
            The value to assign to the job_mode property of this DataPumpSettings.
            Allowed values for this property are: "FULL", "SCHEMA", "TABLE", "TABLESPACE", "TRANSPORTABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type job_mode: str

        :param data_pump_parameters:
            The value to assign to the data_pump_parameters property of this DataPumpSettings.
        :type data_pump_parameters: oci.database_migration.models.DataPumpParameters

        :param metadata_remaps:
            The value to assign to the metadata_remaps property of this DataPumpSettings.
        :type metadata_remaps: list[oci.database_migration.models.MetadataRemap]

        :param export_directory_object:
            The value to assign to the export_directory_object property of this DataPumpSettings.
        :type export_directory_object: oci.database_migration.models.DirectoryObject

        :param import_directory_object:
            The value to assign to the import_directory_object property of this DataPumpSettings.
        :type import_directory_object: oci.database_migration.models.DirectoryObject

        """
        self.swagger_types = {
            'job_mode': 'str',
            'data_pump_parameters': 'DataPumpParameters',
            'metadata_remaps': 'list[MetadataRemap]',
            'export_directory_object': 'DirectoryObject',
            'import_directory_object': 'DirectoryObject'
        }

        self.attribute_map = {
            'job_mode': 'jobMode',
            'data_pump_parameters': 'dataPumpParameters',
            'metadata_remaps': 'metadataRemaps',
            'export_directory_object': 'exportDirectoryObject',
            'import_directory_object': 'importDirectoryObject'
        }

        self._job_mode = None
        self._data_pump_parameters = None
        self._metadata_remaps = None
        self._export_directory_object = None
        self._import_directory_object = None

    @property
    def job_mode(self):
        """
        Gets the job_mode of this DataPumpSettings.
        Data Pump job mode.
        Refer to `Data Pump Export Modes `__

        __ https://docs.oracle.com/en/database/oracle/oracle-database/19/sutil/oracle-data-pump-export-utility.html#GUID-8E497131-6B9B-4CC8-AA50-35F480CAC2C4

        Allowed values for this property are: "FULL", "SCHEMA", "TABLE", "TABLESPACE", "TRANSPORTABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The job_mode of this DataPumpSettings.
        :rtype: str
        """
        return self._job_mode

    @job_mode.setter
    def job_mode(self, job_mode):
        """
        Sets the job_mode of this DataPumpSettings.
        Data Pump job mode.
        Refer to `Data Pump Export Modes `__

        __ https://docs.oracle.com/en/database/oracle/oracle-database/19/sutil/oracle-data-pump-export-utility.html#GUID-8E497131-6B9B-4CC8-AA50-35F480CAC2C4


        :param job_mode: The job_mode of this DataPumpSettings.
        :type: str
        """
        allowed_values = ["FULL", "SCHEMA", "TABLE", "TABLESPACE", "TRANSPORTABLE"]
        if not value_allowed_none_or_none_sentinel(job_mode, allowed_values):
            job_mode = 'UNKNOWN_ENUM_VALUE'
        self._job_mode = job_mode

    @property
    def data_pump_parameters(self):
        """
        Gets the data_pump_parameters of this DataPumpSettings.

        :return: The data_pump_parameters of this DataPumpSettings.
        :rtype: oci.database_migration.models.DataPumpParameters
        """
        return self._data_pump_parameters

    @data_pump_parameters.setter
    def data_pump_parameters(self, data_pump_parameters):
        """
        Sets the data_pump_parameters of this DataPumpSettings.

        :param data_pump_parameters: The data_pump_parameters of this DataPumpSettings.
        :type: oci.database_migration.models.DataPumpParameters
        """
        self._data_pump_parameters = data_pump_parameters

    @property
    def metadata_remaps(self):
        """
        Gets the metadata_remaps of this DataPumpSettings.
        Defines remapping to be applied to objects as they are processed.
        Refer to `METADATA_REMAP Procedure `__

        __ https://docs.oracle.com/en/database/oracle/oracle-database/19/arpls/DBMS_DATAPUMP.html#GUID-0FC32790-91E6-4781-87A3-229DE024CB3D


        :return: The metadata_remaps of this DataPumpSettings.
        :rtype: list[oci.database_migration.models.MetadataRemap]
        """
        return self._metadata_remaps

    @metadata_remaps.setter
    def metadata_remaps(self, metadata_remaps):
        """
        Sets the metadata_remaps of this DataPumpSettings.
        Defines remapping to be applied to objects as they are processed.
        Refer to `METADATA_REMAP Procedure `__

        __ https://docs.oracle.com/en/database/oracle/oracle-database/19/arpls/DBMS_DATAPUMP.html#GUID-0FC32790-91E6-4781-87A3-229DE024CB3D


        :param metadata_remaps: The metadata_remaps of this DataPumpSettings.
        :type: list[oci.database_migration.models.MetadataRemap]
        """
        self._metadata_remaps = metadata_remaps

    @property
    def export_directory_object(self):
        """
        Gets the export_directory_object of this DataPumpSettings.

        :return: The export_directory_object of this DataPumpSettings.
        :rtype: oci.database_migration.models.DirectoryObject
        """
        return self._export_directory_object

    @export_directory_object.setter
    def export_directory_object(self, export_directory_object):
        """
        Sets the export_directory_object of this DataPumpSettings.

        :param export_directory_object: The export_directory_object of this DataPumpSettings.
        :type: oci.database_migration.models.DirectoryObject
        """
        self._export_directory_object = export_directory_object

    @property
    def import_directory_object(self):
        """
        Gets the import_directory_object of this DataPumpSettings.

        :return: The import_directory_object of this DataPumpSettings.
        :rtype: oci.database_migration.models.DirectoryObject
        """
        return self._import_directory_object

    @import_directory_object.setter
    def import_directory_object(self, import_directory_object):
        """
        Sets the import_directory_object of this DataPumpSettings.

        :param import_directory_object: The import_directory_object of this DataPumpSettings.
        :type: oci.database_migration.models.DirectoryObject
        """
        self._import_directory_object = import_directory_object

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .availability_domain import AvailabilityDomain
from .blockchain_platform import BlockchainPlatform
from .blockchain_platform_by_hostname import BlockchainPlatformByHostname
from .blockchain_platform_collection import BlockchainPlatformCollection
from .blockchain_platform_component_details import BlockchainPlatformComponentDetails
from .blockchain_platform_summary import BlockchainPlatformSummary
from .change_blockchain_platform_compartment_details import ChangeBlockchainPlatformCompartmentDetails
from .create_blockchain_platform_details import CreateBlockchainPlatformDetails
from .create_osn_details import CreateOsnDetails
from .create_peer_details import CreatePeerDetails
from .metadata_details import MetadataDetails
from .modify_peer_details import ModifyPeerDetails
from .ocpu_allocation_number_param import OcpuAllocationNumberParam
from .ocpu_utilization_info import OcpuUtilizationInfo
from .osn import Osn
from .osn_collection import OsnCollection
from .osn_summary import OsnSummary
from .peer import Peer
from .peer_collection import PeerCollection
from .peer_role import PeerRole
from .peer_summary import PeerSummary
from .replica_details import ReplicaDetails
from .scale_blockchain_platform_details import ScaleBlockchainPlatformDetails
from .scale_storage_details import ScaleStorageDetails
from .scaled_blockchain_platform_preview import ScaledBlockchainPlatformPreview
from .scaled_platform_metering_preview import ScaledPlatformMeteringPreview
from .update_blockchain_platform_details import UpdateBlockchainPlatformDetails
from .update_osn_details import UpdateOsnDetails
from .update_peer_details import UpdatePeerDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_resource_sub_type_detail import WorkRequestResourceSubTypeDetail
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for blockchain services.
blockchain_type_mapping = {
    "AvailabilityDomain": AvailabilityDomain,
    "BlockchainPlatform": BlockchainPlatform,
    "BlockchainPlatformByHostname": BlockchainPlatformByHostname,
    "BlockchainPlatformCollection": BlockchainPlatformCollection,
    "BlockchainPlatformComponentDetails": BlockchainPlatformComponentDetails,
    "BlockchainPlatformSummary": BlockchainPlatformSummary,
    "ChangeBlockchainPlatformCompartmentDetails": ChangeBlockchainPlatformCompartmentDetails,
    "CreateBlockchainPlatformDetails": CreateBlockchainPlatformDetails,
    "CreateOsnDetails": CreateOsnDetails,
    "CreatePeerDetails": CreatePeerDetails,
    "MetadataDetails": MetadataDetails,
    "ModifyPeerDetails": ModifyPeerDetails,
    "OcpuAllocationNumberParam": OcpuAllocationNumberParam,
    "OcpuUtilizationInfo": OcpuUtilizationInfo,
    "Osn": Osn,
    "OsnCollection": OsnCollection,
    "OsnSummary": OsnSummary,
    "Peer": Peer,
    "PeerCollection": PeerCollection,
    "PeerRole": PeerRole,
    "PeerSummary": PeerSummary,
    "ReplicaDetails": ReplicaDetails,
    "ScaleBlockchainPlatformDetails": ScaleBlockchainPlatformDetails,
    "ScaleStorageDetails": ScaleStorageDetails,
    "ScaledBlockchainPlatformPreview": ScaledBlockchainPlatformPreview,
    "ScaledPlatformMeteringPreview": ScaledPlatformMeteringPreview,
    "UpdateBlockchainPlatformDetails": UpdateBlockchainPlatformDetails,
    "UpdateOsnDetails": UpdateOsnDetails,
    "UpdatePeerDetails": UpdatePeerDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestResourceSubTypeDetail": WorkRequestResourceSubTypeDetail,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateIntegrationInstanceDetails(object):
    """
    The information to be updated.
    """

    #: A constant which can be used with the integration_instance_type property of a UpdateIntegrationInstanceDetails.
    #: This constant has a value of "STANDARD"
    INTEGRATION_INSTANCE_TYPE_STANDARD = "STANDARD"

    #: A constant which can be used with the integration_instance_type property of a UpdateIntegrationInstanceDetails.
    #: This constant has a value of "ENTERPRISE"
    INTEGRATION_INSTANCE_TYPE_ENTERPRISE = "ENTERPRISE"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateIntegrationInstanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateIntegrationInstanceDetails.
        :type display_name: str

        :param integration_instance_type:
            The value to assign to the integration_instance_type property of this UpdateIntegrationInstanceDetails.
            Allowed values for this property are: "STANDARD", "ENTERPRISE"
        :type integration_instance_type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateIntegrationInstanceDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateIntegrationInstanceDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param is_byol:
            The value to assign to the is_byol property of this UpdateIntegrationInstanceDetails.
        :type is_byol: bool

        :param message_packs:
            The value to assign to the message_packs property of this UpdateIntegrationInstanceDetails.
        :type message_packs: int

        :param is_file_server_enabled:
            The value to assign to the is_file_server_enabled property of this UpdateIntegrationInstanceDetails.
        :type is_file_server_enabled: bool

        :param is_visual_builder_enabled:
            The value to assign to the is_visual_builder_enabled property of this UpdateIntegrationInstanceDetails.
        :type is_visual_builder_enabled: bool

        :param custom_endpoint:
            The value to assign to the custom_endpoint property of this UpdateIntegrationInstanceDetails.
        :type custom_endpoint: oci.integration.models.UpdateCustomEndpointDetails

        :param alternate_custom_endpoints:
            The value to assign to the alternate_custom_endpoints property of this UpdateIntegrationInstanceDetails.
        :type alternate_custom_endpoints: list[oci.integration.models.UpdateCustomEndpointDetails]

        """
        self.swagger_types = {
            'display_name': 'str',
            'integration_instance_type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'is_byol': 'bool',
            'message_packs': 'int',
            'is_file_server_enabled': 'bool',
            'is_visual_builder_enabled': 'bool',
            'custom_endpoint': 'UpdateCustomEndpointDetails',
            'alternate_custom_endpoints': 'list[UpdateCustomEndpointDetails]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'integration_instance_type': 'integrationInstanceType',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'is_byol': 'isByol',
            'message_packs': 'messagePacks',
            'is_file_server_enabled': 'isFileServerEnabled',
            'is_visual_builder_enabled': 'isVisualBuilderEnabled',
            'custom_endpoint': 'customEndpoint',
            'alternate_custom_endpoints': 'alternateCustomEndpoints'
        }

        self._display_name = None
        self._integration_instance_type = None
        self._freeform_tags = None
        self._defined_tags = None
        self._is_byol = None
        self._message_packs = None
        self._is_file_server_enabled = None
        self._is_visual_builder_enabled = None
        self._custom_endpoint = None
        self._alternate_custom_endpoints = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateIntegrationInstanceDetails.
        Integration Instance Identifier.


        :return: The display_name of this UpdateIntegrationInstanceDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateIntegrationInstanceDetails.
        Integration Instance Identifier.


        :param display_name: The display_name of this UpdateIntegrationInstanceDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def integration_instance_type(self):
        """
        Gets the integration_instance_type of this UpdateIntegrationInstanceDetails.
        Standard or Enterprise type

        Allowed values for this property are: "STANDARD", "ENTERPRISE"


        :return: The integration_instance_type of this UpdateIntegrationInstanceDetails.
        :rtype: str
        """
        return self._integration_instance_type

    @integration_instance_type.setter
    def integration_instance_type(self, integration_instance_type):
        """
        Sets the integration_instance_type of this UpdateIntegrationInstanceDetails.
        Standard or Enterprise type


        :param integration_instance_type: The integration_instance_type of this UpdateIntegrationInstanceDetails.
        :type: str
        """
        allowed_values = ["STANDARD", "ENTERPRISE"]
        if not value_allowed_none_or_none_sentinel(integration_instance_type, allowed_values):
            raise ValueError(
                "Invalid value for `integration_instance_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._integration_instance_type = integration_instance_type

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateIntegrationInstanceDetails.
        Simple key-value pair that is applied without any predefined name,
        type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateIntegrationInstanceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateIntegrationInstanceDetails.
        Simple key-value pair that is applied without any predefined name,
        type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateIntegrationInstanceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateIntegrationInstanceDetails.
        Usage of predefined tag keys. These predefined keys are scoped to
        namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateIntegrationInstanceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateIntegrationInstanceDetails.
        Usage of predefined tag keys. These predefined keys are scoped to
        namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateIntegrationInstanceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def is_byol(self):
        """
        Gets the is_byol of this UpdateIntegrationInstanceDetails.
        Bring your own license.


        :return: The is_byol of this UpdateIntegrationInstanceDetails.
        :rtype: bool
        """
        return self._is_byol

    @is_byol.setter
    def is_byol(self, is_byol):
        """
        Sets the is_byol of this UpdateIntegrationInstanceDetails.
        Bring your own license.


        :param is_byol: The is_byol of this UpdateIntegrationInstanceDetails.
        :type: bool
        """
        self._is_byol = is_byol

    @property
    def message_packs(self):
        """
        Gets the message_packs of this UpdateIntegrationInstanceDetails.
        The number of configured message packs


        :return: The message_packs of this UpdateIntegrationInstanceDetails.
        :rtype: int
        """
        return self._message_packs

    @message_packs.setter
    def message_packs(self, message_packs):
        """
        Sets the message_packs of this UpdateIntegrationInstanceDetails.
        The number of configured message packs


        :param message_packs: The message_packs of this UpdateIntegrationInstanceDetails.
        :type: int
        """
        self._message_packs = message_packs

    @property
    def is_file_server_enabled(self):
        """
        Gets the is_file_server_enabled of this UpdateIntegrationInstanceDetails.
        The file server is enabled or not.


        :return: The is_file_server_enabled of this UpdateIntegrationInstanceDetails.
        :rtype: bool
        """
        return self._is_file_server_enabled

    @is_file_server_enabled.setter
    def is_file_server_enabled(self, is_file_server_enabled):
        """
        Sets the is_file_server_enabled of this UpdateIntegrationInstanceDetails.
        The file server is enabled or not.


        :param is_file_server_enabled: The is_file_server_enabled of this UpdateIntegrationInstanceDetails.
        :type: bool
        """
        self._is_file_server_enabled = is_file_server_enabled

    @property
    def is_visual_builder_enabled(self):
        """
        Gets the is_visual_builder_enabled of this UpdateIntegrationInstanceDetails.
        Visual Builder is enabled or not.


        :return: The is_visual_builder_enabled of this UpdateIntegrationInstanceDetails.
        :rtype: bool
        """
        return self._is_visual_builder_enabled

    @is_visual_builder_enabled.setter
    def is_visual_builder_enabled(self, is_visual_builder_enabled):
        """
        Sets the is_visual_builder_enabled of this UpdateIntegrationInstanceDetails.
        Visual Builder is enabled or not.


        :param is_visual_builder_enabled: The is_visual_builder_enabled of this UpdateIntegrationInstanceDetails.
        :type: bool
        """
        self._is_visual_builder_enabled = is_visual_builder_enabled

    @property
    def custom_endpoint(self):
        """
        Gets the custom_endpoint of this UpdateIntegrationInstanceDetails.

        :return: The custom_endpoint of this UpdateIntegrationInstanceDetails.
        :rtype: oci.integration.models.UpdateCustomEndpointDetails
        """
        return self._custom_endpoint

    @custom_endpoint.setter
    def custom_endpoint(self, custom_endpoint):
        """
        Sets the custom_endpoint of this UpdateIntegrationInstanceDetails.

        :param custom_endpoint: The custom_endpoint of this UpdateIntegrationInstanceDetails.
        :type: oci.integration.models.UpdateCustomEndpointDetails
        """
        self._custom_endpoint = custom_endpoint

    @property
    def alternate_custom_endpoints(self):
        """
        Gets the alternate_custom_endpoints of this UpdateIntegrationInstanceDetails.
        A list of alternate custom endpoints to be used for the integration instance URL
        (contact Oracle for alternateCustomEndpoints availability for a specific instance).


        :return: The alternate_custom_endpoints of this UpdateIntegrationInstanceDetails.
        :rtype: list[oci.integration.models.UpdateCustomEndpointDetails]
        """
        return self._alternate_custom_endpoints

    @alternate_custom_endpoints.setter
    def alternate_custom_endpoints(self, alternate_custom_endpoints):
        """
        Sets the alternate_custom_endpoints of this UpdateIntegrationInstanceDetails.
        A list of alternate custom endpoints to be used for the integration instance URL
        (contact Oracle for alternateCustomEndpoints availability for a specific instance).


        :param alternate_custom_endpoints: The alternate_custom_endpoints of this UpdateIntegrationInstanceDetails.
        :type: list[oci.integration.models.UpdateCustomEndpointDetails]
        """
        self._alternate_custom_endpoints = alternate_custom_endpoints

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .api_specification_route_backend import ApiSpecificationRouteBackend
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HTTPBackend(ApiSpecificationRouteBackend):
    """
    Send the request to an HTTP backend.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HTTPBackend object with values from keyword arguments. The default value of the :py:attr:`~oci.apigateway.models.HTTPBackend.type` attribute
        of this class is ``HTTP_BACKEND`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this HTTPBackend.
            Allowed values for this property are: "ORACLE_FUNCTIONS_BACKEND", "HTTP_BACKEND", "STOCK_RESPONSE_BACKEND"
        :type type: str

        :param url:
            The value to assign to the url property of this HTTPBackend.
        :type url: str

        :param connect_timeout_in_seconds:
            The value to assign to the connect_timeout_in_seconds property of this HTTPBackend.
        :type connect_timeout_in_seconds: float

        :param read_timeout_in_seconds:
            The value to assign to the read_timeout_in_seconds property of this HTTPBackend.
        :type read_timeout_in_seconds: float

        :param send_timeout_in_seconds:
            The value to assign to the send_timeout_in_seconds property of this HTTPBackend.
        :type send_timeout_in_seconds: float

        :param is_ssl_verify_disabled:
            The value to assign to the is_ssl_verify_disabled property of this HTTPBackend.
        :type is_ssl_verify_disabled: bool

        """
        self.swagger_types = {
            'type': 'str',
            'url': 'str',
            'connect_timeout_in_seconds': 'float',
            'read_timeout_in_seconds': 'float',
            'send_timeout_in_seconds': 'float',
            'is_ssl_verify_disabled': 'bool'
        }

        self.attribute_map = {
            'type': 'type',
            'url': 'url',
            'connect_timeout_in_seconds': 'connectTimeoutInSeconds',
            'read_timeout_in_seconds': 'readTimeoutInSeconds',
            'send_timeout_in_seconds': 'sendTimeoutInSeconds',
            'is_ssl_verify_disabled': 'isSslVerifyDisabled'
        }

        self._type = None
        self._url = None
        self._connect_timeout_in_seconds = None
        self._read_timeout_in_seconds = None
        self._send_timeout_in_seconds = None
        self._is_ssl_verify_disabled = None
        self._type = 'HTTP_BACKEND'

    @property
    def url(self):
        """
        **[Required]** Gets the url of this HTTPBackend.

        :return: The url of this HTTPBackend.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this HTTPBackend.

        :param url: The url of this HTTPBackend.
        :type: str
        """
        self._url = url

    @property
    def connect_timeout_in_seconds(self):
        """
        Gets the connect_timeout_in_seconds of this HTTPBackend.
        Defines a timeout for establishing a connection with a proxied server.


        :return: The connect_timeout_in_seconds of this HTTPBackend.
        :rtype: float
        """
        return self._connect_timeout_in_seconds

    @connect_timeout_in_seconds.setter
    def connect_timeout_in_seconds(self, connect_timeout_in_seconds):
        """
        Sets the connect_timeout_in_seconds of this HTTPBackend.
        Defines a timeout for establishing a connection with a proxied server.


        :param connect_timeout_in_seconds: The connect_timeout_in_seconds of this HTTPBackend.
        :type: float
        """
        self._connect_timeout_in_seconds = connect_timeout_in_seconds

    @property
    def read_timeout_in_seconds(self):
        """
        Gets the read_timeout_in_seconds of this HTTPBackend.
        Defines a timeout for reading a response from the proxied server.


        :return: The read_timeout_in_seconds of this HTTPBackend.
        :rtype: float
        """
        return self._read_timeout_in_seconds

    @read_timeout_in_seconds.setter
    def read_timeout_in_seconds(self, read_timeout_in_seconds):
        """
        Sets the read_timeout_in_seconds of this HTTPBackend.
        Defines a timeout for reading a response from the proxied server.


        :param read_timeout_in_seconds: The read_timeout_in_seconds of this HTTPBackend.
        :type: float
        """
        self._read_timeout_in_seconds = read_timeout_in_seconds

    @property
    def send_timeout_in_seconds(self):
        """
        Gets the send_timeout_in_seconds of this HTTPBackend.
        Defines a timeout for transmitting a request to the proxied server.


        :return: The send_timeout_in_seconds of this HTTPBackend.
        :rtype: float
        """
        return self._send_timeout_in_seconds

    @send_timeout_in_seconds.setter
    def send_timeout_in_seconds(self, send_timeout_in_seconds):
        """
        Sets the send_timeout_in_seconds of this HTTPBackend.
        Defines a timeout for transmitting a request to the proxied server.


        :param send_timeout_in_seconds: The send_timeout_in_seconds of this HTTPBackend.
        :type: float
        """
        self._send_timeout_in_seconds = send_timeout_in_seconds

    @property
    def is_ssl_verify_disabled(self):
        """
        Gets the is_ssl_verify_disabled of this HTTPBackend.
        Defines whether or not to uphold SSL verification.


        :return: The is_ssl_verify_disabled of this HTTPBackend.
        :rtype: bool
        """
        return self._is_ssl_verify_disabled

    @is_ssl_verify_disabled.setter
    def is_ssl_verify_disabled(self, is_ssl_verify_disabled):
        """
        Sets the is_ssl_verify_disabled of this HTTPBackend.
        Defines whether or not to uphold SSL verification.


        :param is_ssl_verify_disabled: The is_ssl_verify_disabled of this HTTPBackend.
        :type: bool
        """
        self._is_ssl_verify_disabled = is_ssl_verify_disabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbSystemPlacement(object):
    """
    The availability domain and fault domain a DB System is placed in.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DbSystemPlacement object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this DbSystemPlacement.
        :type availability_domain: str

        :param fault_domain:
            The value to assign to the fault_domain property of this DbSystemPlacement.
        :type fault_domain: str

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'fault_domain': 'str'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'fault_domain': 'faultDomain'
        }

        self._availability_domain = None
        self._fault_domain = None

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this DbSystemPlacement.
        The availability domain in which the DB System is placed.


        :return: The availability_domain of this DbSystemPlacement.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this DbSystemPlacement.
        The availability domain in which the DB System is placed.


        :param availability_domain: The availability_domain of this DbSystemPlacement.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def fault_domain(self):
        """
        Gets the fault_domain of this DbSystemPlacement.
        The fault domain in which the DB System is placed.


        :return: The fault_domain of this DbSystemPlacement.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this DbSystemPlacement.
        The fault domain in which the DB System is placed.


        :param fault_domain: The fault_domain of this DbSystemPlacement.
        :type: str
        """
        self._fault_domain = fault_domain

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SpanLogCollection(object):
    """
    Definition of span log collection object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SpanLogCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_created:
            The value to assign to the time_created property of this SpanLogCollection.
        :type time_created: datetime

        :param span_logs:
            The value to assign to the span_logs property of this SpanLogCollection.
        :type span_logs: list[oci.apm_traces.models.SpanLog]

        """
        self.swagger_types = {
            'time_created': 'datetime',
            'span_logs': 'list[SpanLog]'
        }

        self.attribute_map = {
            'time_created': 'timeCreated',
            'span_logs': 'spanLogs'
        }

        self._time_created = None
        self._span_logs = None

    @property
    def time_created(self):
        """
        Gets the time_created of this SpanLogCollection.
        Timestamp at which the log is created.


        :return: The time_created of this SpanLogCollection.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SpanLogCollection.
        Timestamp at which the log is created.


        :param time_created: The time_created of this SpanLogCollection.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def span_logs(self):
        """
        Gets the span_logs of this SpanLogCollection.
        List of logs associated with the span at the given timestamp.


        :return: The span_logs of this SpanLogCollection.
        :rtype: list[oci.apm_traces.models.SpanLog]
        """
        return self._span_logs

    @span_logs.setter
    def span_logs(self, span_logs):
        """
        Sets the span_logs of this SpanLogCollection.
        List of logs associated with the span at the given timestamp.


        :param span_logs: The span_logs of this SpanLogCollection.
        :type: list[oci.apm_traces.models.SpanLog]
        """
        self._span_logs = span_logs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci.signer
import threading


SECURITY_TOKEN_FORMAT_STRING = 'ST${}'


class SecurityTokenSigner(oci.signer.AbstractBaseSigner):
    """
    The base signer for signing requests where the API key is a token (e.g. instance principals, service-to-service auth) rather representing
    the details for a specific user.

    This class expects caller to provide the token and the private key whose corresponding public key was provided when requesting the token.
    The headers to sign are also customizable but they default to:

        - date, (request-target), host as generic headers on each request
        - content-length, content-type and x-content-sha256 on as additional headers requests with bodies


    """

    def __init__(self, token, private_key, generic_headers=["date", "(request-target)", "host"], body_headers=["content-length", "content-type", "x-content-sha256"]):
        self.api_key = SECURITY_TOKEN_FORMAT_STRING.format(token)
        self.private_key = private_key

        self.create_signers(self.api_key, self.private_key, generic_headers, body_headers)


class X509FederationClientBasedSecurityTokenSigner(SecurityTokenSigner):
    """
    A SecurityTokenSigner where the token and private key are sourced from a provided X509FederationClient. The token is retrieved via the client's get_security_token()
    method, and the private key is retrieved by reading it from the session_key_supplier in the client.

    The headers to sign are also customizable but they default to:

        - date, (request-target), host as generic headers on each request
        - content-length, content-type and x-content-sha256 on as additional headers requests with bodies


    """

    def __init__(self, federation_client, generic_headers=["date", "(request-target)", "host"], body_headers=["content-length", "content-type", "x-content-sha256"]):
        self.federation_client = federation_client
        self._reset_signers_lock = threading.Lock()

        super(X509FederationClientBasedSecurityTokenSigner, self).__init__(
            self.federation_client.get_security_token(),
            self.federation_client.session_key_supplier.get_key_pair()['private'],
            generic_headers=generic_headers,
            body_headers=body_headers
        )

    def __call__(self, request, enforce_content_headers=True):
        self._reset_signers()
        return super(X509FederationClientBasedSecurityTokenSigner, self).__call__(request, enforce_content_headers)

    def refresh_security_token(self):
        self.federation_client.refresh_security_token()

    def _reset_signers(self):
        self._reset_signers_lock.acquire()
        try:
            refreshed_token = self.federation_client.get_security_token()
            self.api_key = SECURITY_TOKEN_FORMAT_STRING.format(refreshed_token)
            self.private_key = self.federation_client.session_key_supplier.get_key_pair()['private']

            self._basic_signer.reset_signer(self.api_key, self.private_key)
            self._body_signer.reset_signer(self.api_key, self.private_key)
        finally:
            self._reset_signers_lock.release()



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LocalClonePluggableDatabaseDetails(object):
    """
    Parameters for cloning a pluggable database (PDB) within the same database (CDB).

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LocalClonePluggableDatabaseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cloned_pdb_name:
            The value to assign to the cloned_pdb_name property of this LocalClonePluggableDatabaseDetails.
        :type cloned_pdb_name: str

        :param pdb_admin_password:
            The value to assign to the pdb_admin_password property of this LocalClonePluggableDatabaseDetails.
        :type pdb_admin_password: str

        :param target_tde_wallet_password:
            The value to assign to the target_tde_wallet_password property of this LocalClonePluggableDatabaseDetails.
        :type target_tde_wallet_password: str

        """
        self.swagger_types = {
            'cloned_pdb_name': 'str',
            'pdb_admin_password': 'str',
            'target_tde_wallet_password': 'str'
        }

        self.attribute_map = {
            'cloned_pdb_name': 'clonedPdbName',
            'pdb_admin_password': 'pdbAdminPassword',
            'target_tde_wallet_password': 'targetTdeWalletPassword'
        }

        self._cloned_pdb_name = None
        self._pdb_admin_password = None
        self._target_tde_wallet_password = None

    @property
    def cloned_pdb_name(self):
        """
        **[Required]** Gets the cloned_pdb_name of this LocalClonePluggableDatabaseDetails.
        The name for the pluggable database (PDB). The name is unique in the context of a :class:`Database`. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.


        :return: The cloned_pdb_name of this LocalClonePluggableDatabaseDetails.
        :rtype: str
        """
        return self._cloned_pdb_name

    @cloned_pdb_name.setter
    def cloned_pdb_name(self, cloned_pdb_name):
        """
        Sets the cloned_pdb_name of this LocalClonePluggableDatabaseDetails.
        The name for the pluggable database (PDB). The name is unique in the context of a :class:`Database`. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.


        :param cloned_pdb_name: The cloned_pdb_name of this LocalClonePluggableDatabaseDetails.
        :type: str
        """
        self._cloned_pdb_name = cloned_pdb_name

    @property
    def pdb_admin_password(self):
        """
        **[Required]** Gets the pdb_admin_password of this LocalClonePluggableDatabaseDetails.
        A strong password for PDB Admin of the newly cloned PDB. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :return: The pdb_admin_password of this LocalClonePluggableDatabaseDetails.
        :rtype: str
        """
        return self._pdb_admin_password

    @pdb_admin_password.setter
    def pdb_admin_password(self, pdb_admin_password):
        """
        Sets the pdb_admin_password of this LocalClonePluggableDatabaseDetails.
        A strong password for PDB Admin of the newly cloned PDB. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :param pdb_admin_password: The pdb_admin_password of this LocalClonePluggableDatabaseDetails.
        :type: str
        """
        self._pdb_admin_password = pdb_admin_password

    @property
    def target_tde_wallet_password(self):
        """
        **[Required]** Gets the target_tde_wallet_password of this LocalClonePluggableDatabaseDetails.
        The existing TDE wallet password of the target CDB.


        :return: The target_tde_wallet_password of this LocalClonePluggableDatabaseDetails.
        :rtype: str
        """
        return self._target_tde_wallet_password

    @target_tde_wallet_password.setter
    def target_tde_wallet_password(self, target_tde_wallet_password):
        """
        Sets the target_tde_wallet_password of this LocalClonePluggableDatabaseDetails.
        The existing TDE wallet password of the target CDB.


        :param target_tde_wallet_password: The target_tde_wallet_password of this LocalClonePluggableDatabaseDetails.
        :type: str
        """
        self._target_tde_wallet_password = target_tde_wallet_password

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateFolderDetails(object):
    """
    The properties used in folder create operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateFolderDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this CreateFolderDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateFolderDetails.
        :type model_version: str

        :param name:
            The value to assign to the name property of this CreateFolderDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateFolderDetails.
        :type description: str

        :param category_name:
            The value to assign to the category_name property of this CreateFolderDetails.
        :type category_name: str

        :param object_status:
            The value to assign to the object_status property of this CreateFolderDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreateFolderDetails.
        :type identifier: str

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreateFolderDetails.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        """
        self.swagger_types = {
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'category_name': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'category_name': 'categoryName',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'registry_metadata': 'registryMetadata'
        }

        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._category_name = None
        self._object_status = None
        self._identifier = None
        self._registry_metadata = None

    @property
    def key(self):
        """
        Gets the key of this CreateFolderDetails.
        Currently not used on folder creation. Reserved for future.


        :return: The key of this CreateFolderDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this CreateFolderDetails.
        Currently not used on folder creation. Reserved for future.


        :param key: The key of this CreateFolderDetails.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this CreateFolderDetails.
        The model version of an object.


        :return: The model_version of this CreateFolderDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this CreateFolderDetails.
        The model version of an object.


        :param model_version: The model_version of this CreateFolderDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateFolderDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this CreateFolderDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateFolderDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this CreateFolderDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CreateFolderDetails.
        A user defined description for the folder.


        :return: The description of this CreateFolderDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateFolderDetails.
        A user defined description for the folder.


        :param description: The description of this CreateFolderDetails.
        :type: str
        """
        self._description = description

    @property
    def category_name(self):
        """
        Gets the category_name of this CreateFolderDetails.
        The category name.


        :return: The category_name of this CreateFolderDetails.
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """
        Sets the category_name of this CreateFolderDetails.
        The category name.


        :param category_name: The category_name of this CreateFolderDetails.
        :type: str
        """
        self._category_name = category_name

    @property
    def object_status(self):
        """
        Gets the object_status of this CreateFolderDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this CreateFolderDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this CreateFolderDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this CreateFolderDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this CreateFolderDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this CreateFolderDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this CreateFolderDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this CreateFolderDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def registry_metadata(self):
        """
        **[Required]** Gets the registry_metadata of this CreateFolderDetails.

        :return: The registry_metadata of this CreateFolderDetails.
        :rtype: oci.data_integration.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this CreateFolderDetails.

        :param registry_metadata: The registry_metadata of this CreateFolderDetails.
        :type: oci.data_integration.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExternalPublicationSummary(object):
    """
    The external publication summary contains the audit summary information and the definition of the external object.
    """

    #: A constant which can be used with the status property of a ExternalPublicationSummary.
    #: This constant has a value of "SUCCESSFUL"
    STATUS_SUCCESSFUL = "SUCCESSFUL"

    #: A constant which can be used with the status property of a ExternalPublicationSummary.
    #: This constant has a value of "FAILED"
    STATUS_FAILED = "FAILED"

    #: A constant which can be used with the status property of a ExternalPublicationSummary.
    #: This constant has a value of "PUBLISHING"
    STATUS_PUBLISHING = "PUBLISHING"

    def __init__(self, **kwargs):
        """
        Initializes a new ExternalPublicationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param application_id:
            The value to assign to the application_id property of this ExternalPublicationSummary.
        :type application_id: str

        :param application_compartment_id:
            The value to assign to the application_compartment_id property of this ExternalPublicationSummary.
        :type application_compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this ExternalPublicationSummary.
        :type display_name: str

        :param resource_configuration:
            The value to assign to the resource_configuration property of this ExternalPublicationSummary.
        :type resource_configuration: oci.data_integration.models.ResourceConfiguration

        :param configuration_details:
            The value to assign to the configuration_details property of this ExternalPublicationSummary.
        :type configuration_details: oci.data_integration.models.ConfigurationDetails

        :param status:
            The value to assign to the status property of this ExternalPublicationSummary.
            Allowed values for this property are: "SUCCESSFUL", "FAILED", "PUBLISHING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param error_message:
            The value to assign to the error_message property of this ExternalPublicationSummary.
        :type error_message: str

        :param key:
            The value to assign to the key property of this ExternalPublicationSummary.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this ExternalPublicationSummary.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this ExternalPublicationSummary.
        :type model_version: str

        :param name:
            The value to assign to the name property of this ExternalPublicationSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this ExternalPublicationSummary.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this ExternalPublicationSummary.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this ExternalPublicationSummary.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this ExternalPublicationSummary.
        :type identifier: str

        :param parent_ref:
            The value to assign to the parent_ref property of this ExternalPublicationSummary.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param metadata:
            The value to assign to the metadata property of this ExternalPublicationSummary.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this ExternalPublicationSummary.
        :type key_map: dict(str, str)

        """
        self.swagger_types = {
            'application_id': 'str',
            'application_compartment_id': 'str',
            'display_name': 'str',
            'resource_configuration': 'ResourceConfiguration',
            'configuration_details': 'ConfigurationDetails',
            'status': 'str',
            'error_message': 'str',
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'parent_ref': 'ParentReference',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)'
        }

        self.attribute_map = {
            'application_id': 'applicationId',
            'application_compartment_id': 'applicationCompartmentId',
            'display_name': 'displayName',
            'resource_configuration': 'resourceConfiguration',
            'configuration_details': 'configurationDetails',
            'status': 'status',
            'error_message': 'errorMessage',
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parent_ref': 'parentRef',
            'metadata': 'metadata',
            'key_map': 'keyMap'
        }

        self._application_id = None
        self._application_compartment_id = None
        self._display_name = None
        self._resource_configuration = None
        self._configuration_details = None
        self._status = None
        self._error_message = None
        self._key = None
        self._model_type = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._parent_ref = None
        self._metadata = None
        self._key_map = None

    @property
    def application_id(self):
        """
        Gets the application_id of this ExternalPublicationSummary.
        The unique OCID of the identifier that is returned after creating the Oracle Cloud Infrastructure Data Flow application.


        :return: The application_id of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """
        Sets the application_id of this ExternalPublicationSummary.
        The unique OCID of the identifier that is returned after creating the Oracle Cloud Infrastructure Data Flow application.


        :param application_id: The application_id of this ExternalPublicationSummary.
        :type: str
        """
        self._application_id = application_id

    @property
    def application_compartment_id(self):
        """
        Gets the application_compartment_id of this ExternalPublicationSummary.
        The OCID of the compartment where the application is created in the Oracle Cloud Infrastructure Data Flow Service.


        :return: The application_compartment_id of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._application_compartment_id

    @application_compartment_id.setter
    def application_compartment_id(self, application_compartment_id):
        """
        Sets the application_compartment_id of this ExternalPublicationSummary.
        The OCID of the compartment where the application is created in the Oracle Cloud Infrastructure Data Flow Service.


        :param application_compartment_id: The application_compartment_id of this ExternalPublicationSummary.
        :type: str
        """
        self._application_compartment_id = application_compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this ExternalPublicationSummary.
        The name of the application.


        :return: The display_name of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ExternalPublicationSummary.
        The name of the application.


        :param display_name: The display_name of this ExternalPublicationSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def resource_configuration(self):
        """
        Gets the resource_configuration of this ExternalPublicationSummary.

        :return: The resource_configuration of this ExternalPublicationSummary.
        :rtype: oci.data_integration.models.ResourceConfiguration
        """
        return self._resource_configuration

    @resource_configuration.setter
    def resource_configuration(self, resource_configuration):
        """
        Sets the resource_configuration of this ExternalPublicationSummary.

        :param resource_configuration: The resource_configuration of this ExternalPublicationSummary.
        :type: oci.data_integration.models.ResourceConfiguration
        """
        self._resource_configuration = resource_configuration

    @property
    def configuration_details(self):
        """
        Gets the configuration_details of this ExternalPublicationSummary.

        :return: The configuration_details of this ExternalPublicationSummary.
        :rtype: oci.data_integration.models.ConfigurationDetails
        """
        return self._configuration_details

    @configuration_details.setter
    def configuration_details(self, configuration_details):
        """
        Sets the configuration_details of this ExternalPublicationSummary.

        :param configuration_details: The configuration_details of this ExternalPublicationSummary.
        :type: oci.data_integration.models.ConfigurationDetails
        """
        self._configuration_details = configuration_details

    @property
    def status(self):
        """
        Gets the status of this ExternalPublicationSummary.
        The status of the publishing action to Oracle Cloud Infrastructure Data Flow.

        Allowed values for this property are: "SUCCESSFUL", "FAILED", "PUBLISHING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ExternalPublicationSummary.
        The status of the publishing action to Oracle Cloud Infrastructure Data Flow.


        :param status: The status of this ExternalPublicationSummary.
        :type: str
        """
        allowed_values = ["SUCCESSFUL", "FAILED", "PUBLISHING"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def error_message(self):
        """
        Gets the error_message of this ExternalPublicationSummary.
        The error of the published object in the application.


        :return: The error_message of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this ExternalPublicationSummary.
        The error of the published object in the application.


        :param error_message: The error_message of this ExternalPublicationSummary.
        :type: str
        """
        self._error_message = error_message

    @property
    def key(self):
        """
        Gets the key of this ExternalPublicationSummary.
        The object key.


        :return: The key of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ExternalPublicationSummary.
        The object key.


        :param key: The key of this ExternalPublicationSummary.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this ExternalPublicationSummary.
        The object type.


        :return: The model_type of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this ExternalPublicationSummary.
        The object type.


        :param model_type: The model_type of this ExternalPublicationSummary.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this ExternalPublicationSummary.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :return: The model_version of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this ExternalPublicationSummary.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :param model_version: The model_version of this ExternalPublicationSummary.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        Gets the name of this ExternalPublicationSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExternalPublicationSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this ExternalPublicationSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ExternalPublicationSummary.
        Detailed description for the object.


        :return: The description of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ExternalPublicationSummary.
        Detailed description for the object.


        :param description: The description of this ExternalPublicationSummary.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this ExternalPublicationSummary.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this ExternalPublicationSummary.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this ExternalPublicationSummary.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this ExternalPublicationSummary.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this ExternalPublicationSummary.
        The status of an object that can be set to value 1 for shallow references across objects. Other values are reserved.


        :return: The object_status of this ExternalPublicationSummary.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this ExternalPublicationSummary.
        The status of an object that can be set to value 1 for shallow references across objects. Other values are reserved.


        :param object_status: The object_status of this ExternalPublicationSummary.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this ExternalPublicationSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this ExternalPublicationSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this ExternalPublicationSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this ExternalPublicationSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this ExternalPublicationSummary.

        :return: The parent_ref of this ExternalPublicationSummary.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this ExternalPublicationSummary.

        :param parent_ref: The parent_ref of this ExternalPublicationSummary.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def metadata(self):
        """
        Gets the metadata of this ExternalPublicationSummary.

        :return: The metadata of this ExternalPublicationSummary.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this ExternalPublicationSummary.

        :param metadata: The metadata of this ExternalPublicationSummary.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    @property
    def key_map(self):
        """
        Gets the key_map of this ExternalPublicationSummary.
        A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :return: The key_map of this ExternalPublicationSummary.
        :rtype: dict(str, str)
        """
        return self._key_map

    @key_map.setter
    def key_map(self, key_map):
        """
        Sets the key_map of this ExternalPublicationSummary.
        A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :param key_map: The key_map of this ExternalPublicationSummary.
        :type: dict(str, str)
        """
        self._key_map = key_map

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_configuration_metric_group import DatabaseConfigurationMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DBOSConfigInstance(DatabaseConfigurationMetricGroup):
    """
    Configuration parameters defined for external databases instance level.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DBOSConfigInstance object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.DBOSConfigInstance.metric_name` attribute
        of this class is ``DB_OS_CONFIG_INSTANCE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this DBOSConfigInstance.
            Allowed values for this property are: "DB_EXTERNAL_PROPERTIES", "DB_EXTERNAL_INSTANCE", "DB_OS_CONFIG_INSTANCE"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this DBOSConfigInstance.
        :type time_collected: datetime

        :param instance_name:
            The value to assign to the instance_name property of this DBOSConfigInstance.
        :type instance_name: str

        :param host_name:
            The value to assign to the host_name property of this DBOSConfigInstance.
        :type host_name: str

        :param num_cp_us:
            The value to assign to the num_cp_us property of this DBOSConfigInstance.
        :type num_cp_us: int

        :param num_cpu_cores:
            The value to assign to the num_cpu_cores property of this DBOSConfigInstance.
        :type num_cpu_cores: int

        :param num_cpu_sockets:
            The value to assign to the num_cpu_sockets property of this DBOSConfigInstance.
        :type num_cpu_sockets: int

        :param physical_memory_bytes:
            The value to assign to the physical_memory_bytes property of this DBOSConfigInstance.
        :type physical_memory_bytes: float

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'instance_name': 'str',
            'host_name': 'str',
            'num_cp_us': 'int',
            'num_cpu_cores': 'int',
            'num_cpu_sockets': 'int',
            'physical_memory_bytes': 'float'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'instance_name': 'instanceName',
            'host_name': 'hostName',
            'num_cp_us': 'numCPUs',
            'num_cpu_cores': 'numCPUCores',
            'num_cpu_sockets': 'numCPUSockets',
            'physical_memory_bytes': 'physicalMemoryBytes'
        }

        self._metric_name = None
        self._time_collected = None
        self._instance_name = None
        self._host_name = None
        self._num_cp_us = None
        self._num_cpu_cores = None
        self._num_cpu_sockets = None
        self._physical_memory_bytes = None
        self._metric_name = 'DB_OS_CONFIG_INSTANCE'

    @property
    def instance_name(self):
        """
        **[Required]** Gets the instance_name of this DBOSConfigInstance.
        Name of the database instance.


        :return: The instance_name of this DBOSConfigInstance.
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """
        Sets the instance_name of this DBOSConfigInstance.
        Name of the database instance.


        :param instance_name: The instance_name of this DBOSConfigInstance.
        :type: str
        """
        self._instance_name = instance_name

    @property
    def host_name(self):
        """
        **[Required]** Gets the host_name of this DBOSConfigInstance.
        Host name of the database instance.


        :return: The host_name of this DBOSConfigInstance.
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """
        Sets the host_name of this DBOSConfigInstance.
        Host name of the database instance.


        :param host_name: The host_name of this DBOSConfigInstance.
        :type: str
        """
        self._host_name = host_name

    @property
    def num_cp_us(self):
        """
        Gets the num_cp_us of this DBOSConfigInstance.
        Total number of CPUs available.


        :return: The num_cp_us of this DBOSConfigInstance.
        :rtype: int
        """
        return self._num_cp_us

    @num_cp_us.setter
    def num_cp_us(self, num_cp_us):
        """
        Sets the num_cp_us of this DBOSConfigInstance.
        Total number of CPUs available.


        :param num_cp_us: The num_cp_us of this DBOSConfigInstance.
        :type: int
        """
        self._num_cp_us = num_cp_us

    @property
    def num_cpu_cores(self):
        """
        Gets the num_cpu_cores of this DBOSConfigInstance.
        Number of CPU cores available (includes subcores of multicore CPUs as well as single-core CPUs).


        :return: The num_cpu_cores of this DBOSConfigInstance.
        :rtype: int
        """
        return self._num_cpu_cores

    @num_cpu_cores.setter
    def num_cpu_cores(self, num_cpu_cores):
        """
        Sets the num_cpu_cores of this DBOSConfigInstance.
        Number of CPU cores available (includes subcores of multicore CPUs as well as single-core CPUs).


        :param num_cpu_cores: The num_cpu_cores of this DBOSConfigInstance.
        :type: int
        """
        self._num_cpu_cores = num_cpu_cores

    @property
    def num_cpu_sockets(self):
        """
        Gets the num_cpu_sockets of this DBOSConfigInstance.
        Number of CPU Sockets available.


        :return: The num_cpu_sockets of this DBOSConfigInstance.
        :rtype: int
        """
        return self._num_cpu_sockets

    @num_cpu_sockets.setter
    def num_cpu_sockets(self, num_cpu_sockets):
        """
        Sets the num_cpu_sockets of this DBOSConfigInstance.
        Number of CPU Sockets available.


        :param num_cpu_sockets: The num_cpu_sockets of this DBOSConfigInstance.
        :type: int
        """
        self._num_cpu_sockets = num_cpu_sockets

    @property
    def physical_memory_bytes(self):
        """
        Gets the physical_memory_bytes of this DBOSConfigInstance.
        Total number of bytes of physical memory.


        :return: The physical_memory_bytes of this DBOSConfigInstance.
        :rtype: float
        """
        return self._physical_memory_bytes

    @physical_memory_bytes.setter
    def physical_memory_bytes(self, physical_memory_bytes):
        """
        Sets the physical_memory_bytes of this DBOSConfigInstance.
        Total number of bytes of physical memory.


        :param physical_memory_bytes: The physical_memory_bytes of this DBOSConfigInstance.
        :type: float
        """
        self._physical_memory_bytes = physical_memory_bytes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GrokPattern(object):
    """
    grok pattern object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GrokPattern object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param pattern:
            The value to assign to the pattern property of this GrokPattern.
        :type pattern: str

        :param name:
            The value to assign to the name property of this GrokPattern.
        :type name: str

        :param field_time_key:
            The value to assign to the field_time_key property of this GrokPattern.
        :type field_time_key: str

        :param field_time_format:
            The value to assign to the field_time_format property of this GrokPattern.
        :type field_time_format: str

        :param field_time_zone:
            The value to assign to the field_time_zone property of this GrokPattern.
        :type field_time_zone: str

        """
        self.swagger_types = {
            'pattern': 'str',
            'name': 'str',
            'field_time_key': 'str',
            'field_time_format': 'str',
            'field_time_zone': 'str'
        }

        self.attribute_map = {
            'pattern': 'pattern',
            'name': 'name',
            'field_time_key': 'fieldTimeKey',
            'field_time_format': 'fieldTimeFormat',
            'field_time_zone': 'fieldTimeZone'
        }

        self._pattern = None
        self._name = None
        self._field_time_key = None
        self._field_time_format = None
        self._field_time_zone = None

    @property
    def pattern(self):
        """
        **[Required]** Gets the pattern of this GrokPattern.
        The grok pattern.


        :return: The pattern of this GrokPattern.
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """
        Sets the pattern of this GrokPattern.
        The grok pattern.


        :param pattern: The pattern of this GrokPattern.
        :type: str
        """
        self._pattern = pattern

    @property
    def name(self):
        """
        Gets the name of this GrokPattern.
        The name key to tag this grok pattern.


        :return: The name of this GrokPattern.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this GrokPattern.
        The name key to tag this grok pattern.


        :param name: The name of this GrokPattern.
        :type: str
        """
        self._name = name

    @property
    def field_time_key(self):
        """
        Gets the field_time_key of this GrokPattern.
        Specify the time field for the event time. If the event doesn't have this field, the current time is used.


        :return: The field_time_key of this GrokPattern.
        :rtype: str
        """
        return self._field_time_key

    @field_time_key.setter
    def field_time_key(self, field_time_key):
        """
        Sets the field_time_key of this GrokPattern.
        Specify the time field for the event time. If the event doesn't have this field, the current time is used.


        :param field_time_key: The field_time_key of this GrokPattern.
        :type: str
        """
        self._field_time_key = field_time_key

    @property
    def field_time_format(self):
        """
        Gets the field_time_format of this GrokPattern.
        Process value using the specified format. This is available only when time_type is a string.


        :return: The field_time_format of this GrokPattern.
        :rtype: str
        """
        return self._field_time_format

    @field_time_format.setter
    def field_time_format(self, field_time_format):
        """
        Sets the field_time_format of this GrokPattern.
        Process value using the specified format. This is available only when time_type is a string.


        :param field_time_format: The field_time_format of this GrokPattern.
        :type: str
        """
        self._field_time_format = field_time_format

    @property
    def field_time_zone(self):
        """
        Gets the field_time_zone of this GrokPattern.
        Use the specified time zone. The time value can be parsed or formatted in the specified time zone.


        :return: The field_time_zone of this GrokPattern.
        :rtype: str
        """
        return self._field_time_zone

    @field_time_zone.setter
    def field_time_zone(self, field_time_zone):
        """
        Sets the field_time_zone of this GrokPattern.
        Use the specified time zone. The time value can be parsed or formatted in the specified time zone.


        :param field_time_zone: The field_time_zone of this GrokPattern.
        :type: str
        """
        self._field_time_zone = field_time_zone

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDatabaseDataguardAssociation(object):
    """
    The properties that define dataguard association between two different Autonomous Databases.
    Note that Autonomous Databases inherit DataGuard association from parent Autonomous Container Database.
    No actions can be taken on AutonomousDatabaseDataguardAssociation, usage is strictly informational.
    """

    #: A constant which can be used with the role property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "PRIMARY"
    ROLE_PRIMARY = "PRIMARY"

    #: A constant which can be used with the role property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "STANDBY"
    ROLE_STANDBY = "STANDBY"

    #: A constant which can be used with the role property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "DISABLED_STANDBY"
    ROLE_DISABLED_STANDBY = "DISABLED_STANDBY"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "ROLE_CHANGE_IN_PROGRESS"
    LIFECYCLE_STATE_ROLE_CHANGE_IN_PROGRESS = "ROLE_CHANGE_IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "UNAVAILABLE"
    LIFECYCLE_STATE_UNAVAILABLE = "UNAVAILABLE"

    #: A constant which can be used with the peer_role property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "PRIMARY"
    PEER_ROLE_PRIMARY = "PRIMARY"

    #: A constant which can be used with the peer_role property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "STANDBY"
    PEER_ROLE_STANDBY = "STANDBY"

    #: A constant which can be used with the peer_role property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "DISABLED_STANDBY"
    PEER_ROLE_DISABLED_STANDBY = "DISABLED_STANDBY"

    #: A constant which can be used with the peer_autonomous_database_life_cycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "PROVISIONING"
    PEER_AUTONOMOUS_DATABASE_LIFE_CYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the peer_autonomous_database_life_cycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "AVAILABLE"
    PEER_AUTONOMOUS_DATABASE_LIFE_CYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the peer_autonomous_database_life_cycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "ROLE_CHANGE_IN_PROGRESS"
    PEER_AUTONOMOUS_DATABASE_LIFE_CYCLE_STATE_ROLE_CHANGE_IN_PROGRESS = "ROLE_CHANGE_IN_PROGRESS"

    #: A constant which can be used with the peer_autonomous_database_life_cycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "TERMINATING"
    PEER_AUTONOMOUS_DATABASE_LIFE_CYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the peer_autonomous_database_life_cycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "TERMINATED"
    PEER_AUTONOMOUS_DATABASE_LIFE_CYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the peer_autonomous_database_life_cycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "FAILED"
    PEER_AUTONOMOUS_DATABASE_LIFE_CYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the peer_autonomous_database_life_cycle_state property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "UNAVAILABLE"
    PEER_AUTONOMOUS_DATABASE_LIFE_CYCLE_STATE_UNAVAILABLE = "UNAVAILABLE"

    #: A constant which can be used with the protection_mode property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "MAXIMUM_AVAILABILITY"
    PROTECTION_MODE_MAXIMUM_AVAILABILITY = "MAXIMUM_AVAILABILITY"

    #: A constant which can be used with the protection_mode property of a AutonomousDatabaseDataguardAssociation.
    #: This constant has a value of "MAXIMUM_PERFORMANCE"
    PROTECTION_MODE_MAXIMUM_PERFORMANCE = "MAXIMUM_PERFORMANCE"

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDatabaseDataguardAssociation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AutonomousDatabaseDataguardAssociation.
        :type id: str

        :param autonomous_database_id:
            The value to assign to the autonomous_database_id property of this AutonomousDatabaseDataguardAssociation.
        :type autonomous_database_id: str

        :param role:
            The value to assign to the role property of this AutonomousDatabaseDataguardAssociation.
            Allowed values for this property are: "PRIMARY", "STANDBY", "DISABLED_STANDBY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type role: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AutonomousDatabaseDataguardAssociation.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "ROLE_CHANGE_IN_PROGRESS", "TERMINATING", "TERMINATED", "FAILED", "UNAVAILABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this AutonomousDatabaseDataguardAssociation.
        :type lifecycle_details: str

        :param peer_role:
            The value to assign to the peer_role property of this AutonomousDatabaseDataguardAssociation.
            Allowed values for this property are: "PRIMARY", "STANDBY", "DISABLED_STANDBY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type peer_role: str

        :param peer_autonomous_database_id:
            The value to assign to the peer_autonomous_database_id property of this AutonomousDatabaseDataguardAssociation.
        :type peer_autonomous_database_id: str

        :param peer_autonomous_database_life_cycle_state:
            The value to assign to the peer_autonomous_database_life_cycle_state property of this AutonomousDatabaseDataguardAssociation.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "ROLE_CHANGE_IN_PROGRESS", "TERMINATING", "TERMINATED", "FAILED", "UNAVAILABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type peer_autonomous_database_life_cycle_state: str

        :param protection_mode:
            The value to assign to the protection_mode property of this AutonomousDatabaseDataguardAssociation.
            Allowed values for this property are: "MAXIMUM_AVAILABILITY", "MAXIMUM_PERFORMANCE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type protection_mode: str

        :param apply_lag:
            The value to assign to the apply_lag property of this AutonomousDatabaseDataguardAssociation.
        :type apply_lag: str

        :param apply_rate:
            The value to assign to the apply_rate property of this AutonomousDatabaseDataguardAssociation.
        :type apply_rate: str

        :param transport_lag:
            The value to assign to the transport_lag property of this AutonomousDatabaseDataguardAssociation.
        :type transport_lag: str

        :param time_last_synced:
            The value to assign to the time_last_synced property of this AutonomousDatabaseDataguardAssociation.
        :type time_last_synced: datetime

        :param time_created:
            The value to assign to the time_created property of this AutonomousDatabaseDataguardAssociation.
        :type time_created: datetime

        :param time_last_role_changed:
            The value to assign to the time_last_role_changed property of this AutonomousDatabaseDataguardAssociation.
        :type time_last_role_changed: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'autonomous_database_id': 'str',
            'role': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'peer_role': 'str',
            'peer_autonomous_database_id': 'str',
            'peer_autonomous_database_life_cycle_state': 'str',
            'protection_mode': 'str',
            'apply_lag': 'str',
            'apply_rate': 'str',
            'transport_lag': 'str',
            'time_last_synced': 'datetime',
            'time_created': 'datetime',
            'time_last_role_changed': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'autonomous_database_id': 'autonomousDatabaseId',
            'role': 'role',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'peer_role': 'peerRole',
            'peer_autonomous_database_id': 'peerAutonomousDatabaseId',
            'peer_autonomous_database_life_cycle_state': 'peerAutonomousDatabaseLifeCycleState',
            'protection_mode': 'protectionMode',
            'apply_lag': 'applyLag',
            'apply_rate': 'applyRate',
            'transport_lag': 'transportLag',
            'time_last_synced': 'timeLastSynced',
            'time_created': 'timeCreated',
            'time_last_role_changed': 'timeLastRoleChanged'
        }

        self._id = None
        self._autonomous_database_id = None
        self._role = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._peer_role = None
        self._peer_autonomous_database_id = None
        self._peer_autonomous_database_life_cycle_state = None
        self._protection_mode = None
        self._apply_lag = None
        self._apply_rate = None
        self._transport_lag = None
        self._time_last_synced = None
        self._time_created = None
        self._time_last_role_changed = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AutonomousDatabaseDataguardAssociation.
        The OCID of the Autonomous Dataguard created for Autonomous Container Database where given Autonomous Database resides in.


        :return: The id of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AutonomousDatabaseDataguardAssociation.
        The OCID of the Autonomous Dataguard created for Autonomous Container Database where given Autonomous Database resides in.


        :param id: The id of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        self._id = id

    @property
    def autonomous_database_id(self):
        """
        **[Required]** Gets the autonomous_database_id of this AutonomousDatabaseDataguardAssociation.
        The `OCID`__ of the Autonomous Database that has a relationship with the peer Autonomous Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The autonomous_database_id of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._autonomous_database_id

    @autonomous_database_id.setter
    def autonomous_database_id(self, autonomous_database_id):
        """
        Sets the autonomous_database_id of this AutonomousDatabaseDataguardAssociation.
        The `OCID`__ of the Autonomous Database that has a relationship with the peer Autonomous Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param autonomous_database_id: The autonomous_database_id of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        self._autonomous_database_id = autonomous_database_id

    @property
    def role(self):
        """
        **[Required]** Gets the role of this AutonomousDatabaseDataguardAssociation.
        The Data Guard role of the Autonomous Container Database or Autonomous Database, if Autonomous Data Guard is enabled.

        Allowed values for this property are: "PRIMARY", "STANDBY", "DISABLED_STANDBY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The role of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """
        Sets the role of this AutonomousDatabaseDataguardAssociation.
        The Data Guard role of the Autonomous Container Database or Autonomous Database, if Autonomous Data Guard is enabled.


        :param role: The role of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        allowed_values = ["PRIMARY", "STANDBY", "DISABLED_STANDBY"]
        if not value_allowed_none_or_none_sentinel(role, allowed_values):
            role = 'UNKNOWN_ENUM_VALUE'
        self._role = role

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AutonomousDatabaseDataguardAssociation.
        The current state of Autonomous Data Guard.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "ROLE_CHANGE_IN_PROGRESS", "TERMINATING", "TERMINATED", "FAILED", "UNAVAILABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AutonomousDatabaseDataguardAssociation.
        The current state of Autonomous Data Guard.


        :param lifecycle_state: The lifecycle_state of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "ROLE_CHANGE_IN_PROGRESS", "TERMINATING", "TERMINATED", "FAILED", "UNAVAILABLE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this AutonomousDatabaseDataguardAssociation.
        Additional information about the current lifecycleState, if available.


        :return: The lifecycle_details of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this AutonomousDatabaseDataguardAssociation.
        Additional information about the current lifecycleState, if available.


        :param lifecycle_details: The lifecycle_details of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def peer_role(self):
        """
        **[Required]** Gets the peer_role of this AutonomousDatabaseDataguardAssociation.
        The Data Guard role of the Autonomous Container Database or Autonomous Database, if Autonomous Data Guard is enabled.

        Allowed values for this property are: "PRIMARY", "STANDBY", "DISABLED_STANDBY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The peer_role of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._peer_role

    @peer_role.setter
    def peer_role(self, peer_role):
        """
        Sets the peer_role of this AutonomousDatabaseDataguardAssociation.
        The Data Guard role of the Autonomous Container Database or Autonomous Database, if Autonomous Data Guard is enabled.


        :param peer_role: The peer_role of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        allowed_values = ["PRIMARY", "STANDBY", "DISABLED_STANDBY"]
        if not value_allowed_none_or_none_sentinel(peer_role, allowed_values):
            peer_role = 'UNKNOWN_ENUM_VALUE'
        self._peer_role = peer_role

    @property
    def peer_autonomous_database_id(self):
        """
        Gets the peer_autonomous_database_id of this AutonomousDatabaseDataguardAssociation.
        The `OCID`__ of the peer Autonomous Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The peer_autonomous_database_id of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._peer_autonomous_database_id

    @peer_autonomous_database_id.setter
    def peer_autonomous_database_id(self, peer_autonomous_database_id):
        """
        Sets the peer_autonomous_database_id of this AutonomousDatabaseDataguardAssociation.
        The `OCID`__ of the peer Autonomous Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param peer_autonomous_database_id: The peer_autonomous_database_id of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        self._peer_autonomous_database_id = peer_autonomous_database_id

    @property
    def peer_autonomous_database_life_cycle_state(self):
        """
        Gets the peer_autonomous_database_life_cycle_state of this AutonomousDatabaseDataguardAssociation.
        The current state of Autonomous Data Guard.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "ROLE_CHANGE_IN_PROGRESS", "TERMINATING", "TERMINATED", "FAILED", "UNAVAILABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The peer_autonomous_database_life_cycle_state of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._peer_autonomous_database_life_cycle_state

    @peer_autonomous_database_life_cycle_state.setter
    def peer_autonomous_database_life_cycle_state(self, peer_autonomous_database_life_cycle_state):
        """
        Sets the peer_autonomous_database_life_cycle_state of this AutonomousDatabaseDataguardAssociation.
        The current state of Autonomous Data Guard.


        :param peer_autonomous_database_life_cycle_state: The peer_autonomous_database_life_cycle_state of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "ROLE_CHANGE_IN_PROGRESS", "TERMINATING", "TERMINATED", "FAILED", "UNAVAILABLE"]
        if not value_allowed_none_or_none_sentinel(peer_autonomous_database_life_cycle_state, allowed_values):
            peer_autonomous_database_life_cycle_state = 'UNKNOWN_ENUM_VALUE'
        self._peer_autonomous_database_life_cycle_state = peer_autonomous_database_life_cycle_state

    @property
    def protection_mode(self):
        """
        Gets the protection_mode of this AutonomousDatabaseDataguardAssociation.
        The protection mode of this Data Guard association. For more information, see
        `Oracle Data Guard Protection Modes`__
        in the Oracle Data Guard documentation.

        __ http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000

        Allowed values for this property are: "MAXIMUM_AVAILABILITY", "MAXIMUM_PERFORMANCE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The protection_mode of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._protection_mode

    @protection_mode.setter
    def protection_mode(self, protection_mode):
        """
        Sets the protection_mode of this AutonomousDatabaseDataguardAssociation.
        The protection mode of this Data Guard association. For more information, see
        `Oracle Data Guard Protection Modes`__
        in the Oracle Data Guard documentation.

        __ http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000


        :param protection_mode: The protection_mode of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        allowed_values = ["MAXIMUM_AVAILABILITY", "MAXIMUM_PERFORMANCE"]
        if not value_allowed_none_or_none_sentinel(protection_mode, allowed_values):
            protection_mode = 'UNKNOWN_ENUM_VALUE'
        self._protection_mode = protection_mode

    @property
    def apply_lag(self):
        """
        Gets the apply_lag of this AutonomousDatabaseDataguardAssociation.
        The lag time between updates to the primary database and application of the redo data on the standby database,
        as computed by the reporting database.

        Example: `9 seconds`


        :return: The apply_lag of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._apply_lag

    @apply_lag.setter
    def apply_lag(self, apply_lag):
        """
        Sets the apply_lag of this AutonomousDatabaseDataguardAssociation.
        The lag time between updates to the primary database and application of the redo data on the standby database,
        as computed by the reporting database.

        Example: `9 seconds`


        :param apply_lag: The apply_lag of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        self._apply_lag = apply_lag

    @property
    def apply_rate(self):
        """
        Gets the apply_rate of this AutonomousDatabaseDataguardAssociation.
        The rate at which redo logs are synced between the associated databases.

        Example: `180 Mb per second`


        :return: The apply_rate of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._apply_rate

    @apply_rate.setter
    def apply_rate(self, apply_rate):
        """
        Sets the apply_rate of this AutonomousDatabaseDataguardAssociation.
        The rate at which redo logs are synced between the associated databases.

        Example: `180 Mb per second`


        :param apply_rate: The apply_rate of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        self._apply_rate = apply_rate

    @property
    def transport_lag(self):
        """
        Gets the transport_lag of this AutonomousDatabaseDataguardAssociation.
        The approximate number of seconds of redo data not yet available on the standby Autonomous Container Database,
        as computed by the reporting database.

        Example: `7 seconds`


        :return: The transport_lag of this AutonomousDatabaseDataguardAssociation.
        :rtype: str
        """
        return self._transport_lag

    @transport_lag.setter
    def transport_lag(self, transport_lag):
        """
        Sets the transport_lag of this AutonomousDatabaseDataguardAssociation.
        The approximate number of seconds of redo data not yet available on the standby Autonomous Container Database,
        as computed by the reporting database.

        Example: `7 seconds`


        :param transport_lag: The transport_lag of this AutonomousDatabaseDataguardAssociation.
        :type: str
        """
        self._transport_lag = transport_lag

    @property
    def time_last_synced(self):
        """
        Gets the time_last_synced of this AutonomousDatabaseDataguardAssociation.
        The date and time of the last update to the apply lag, apply rate, and transport lag values.


        :return: The time_last_synced of this AutonomousDatabaseDataguardAssociation.
        :rtype: datetime
        """
        return self._time_last_synced

    @time_last_synced.setter
    def time_last_synced(self, time_last_synced):
        """
        Sets the time_last_synced of this AutonomousDatabaseDataguardAssociation.
        The date and time of the last update to the apply lag, apply rate, and transport lag values.


        :param time_last_synced: The time_last_synced of this AutonomousDatabaseDataguardAssociation.
        :type: datetime
        """
        self._time_last_synced = time_last_synced

    @property
    def time_created(self):
        """
        Gets the time_created of this AutonomousDatabaseDataguardAssociation.
        The date and time the Data Guard association was created.


        :return: The time_created of this AutonomousDatabaseDataguardAssociation.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AutonomousDatabaseDataguardAssociation.
        The date and time the Data Guard association was created.


        :param time_created: The time_created of this AutonomousDatabaseDataguardAssociation.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_last_role_changed(self):
        """
        Gets the time_last_role_changed of this AutonomousDatabaseDataguardAssociation.
        The date and time when the last role change action happened.


        :return: The time_last_role_changed of this AutonomousDatabaseDataguardAssociation.
        :rtype: datetime
        """
        return self._time_last_role_changed

    @time_last_role_changed.setter
    def time_last_role_changed(self, time_last_role_changed):
        """
        Sets the time_last_role_changed of this AutonomousDatabaseDataguardAssociation.
        The date and time when the last role change action happened.


        :param time_last_role_changed: The time_last_role_changed of this AutonomousDatabaseDataguardAssociation.
        :type: datetime
        """
        self._time_last_role_changed = time_last_role_changed

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import io
import os
import re
from setuptools import setup, find_packages


def open_relative(*path):
    """
    Opens files in read-only with a fixed utf-8 encoding.

    All locations are relative to this setup.py file.
    """
    here = os.path.abspath(os.path.dirname(__file__))
    filename = os.path.join(here, *path)
    return io.open(filename, mode="r", encoding="utf-8")


with open_relative("src", "oci", "version.py") as fd:
    version = re.search(
        r"^__version__\s*=\s*['\"]([^'\"]*)['\"]",
        fd.read(), re.MULTILINE).group(1)
    if not version:
        raise RuntimeError("Cannot find version information")

with open_relative("README.rst") as f:
    readme = f.read()

requires = [
    "certifi",
    "configparser==4.0.2 ; python_version < '3'",
    "cryptography>=3.2.1,<=3.4.7",
    "pyOpenSSL>=17.5.0,<=19.1.0",
    "python-dateutil>=2.5.3,<3.0.0",
    "pytz>=2016.10",
]

setup(
    name="oci",
    url="https://docs.oracle.com/en-us/iaas/tools/python/latest/index.html",
    version=version,
    description="Oracle Cloud Infrastructure Python SDK",
    long_description=readme,
    author="Oracle",
    author_email="joe.levy@oracle.com",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    include_package_data=True,
    install_requires=requires,
    license="Universal Permissive License 1.0 or Apache License 2.0",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "License :: OSI Approved :: Universal Permissive License (UPL)",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ]
)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .attach_volume_details import AttachVolumeDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AttachServiceDeterminedVolumeDetails(AttachVolumeDetails):
    """
    AttachServiceDeterminedVolumeDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AttachServiceDeterminedVolumeDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.AttachServiceDeterminedVolumeDetails.type` attribute
        of this class is ``service_determined`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param device:
            The value to assign to the device property of this AttachServiceDeterminedVolumeDetails.
        :type device: str

        :param display_name:
            The value to assign to the display_name property of this AttachServiceDeterminedVolumeDetails.
        :type display_name: str

        :param instance_id:
            The value to assign to the instance_id property of this AttachServiceDeterminedVolumeDetails.
        :type instance_id: str

        :param is_read_only:
            The value to assign to the is_read_only property of this AttachServiceDeterminedVolumeDetails.
        :type is_read_only: bool

        :param is_shareable:
            The value to assign to the is_shareable property of this AttachServiceDeterminedVolumeDetails.
        :type is_shareable: bool

        :param type:
            The value to assign to the type property of this AttachServiceDeterminedVolumeDetails.
        :type type: str

        :param volume_id:
            The value to assign to the volume_id property of this AttachServiceDeterminedVolumeDetails.
        :type volume_id: str

        """
        self.swagger_types = {
            'device': 'str',
            'display_name': 'str',
            'instance_id': 'str',
            'is_read_only': 'bool',
            'is_shareable': 'bool',
            'type': 'str',
            'volume_id': 'str'
        }

        self.attribute_map = {
            'device': 'device',
            'display_name': 'displayName',
            'instance_id': 'instanceId',
            'is_read_only': 'isReadOnly',
            'is_shareable': 'isShareable',
            'type': 'type',
            'volume_id': 'volumeId'
        }

        self._device = None
        self._display_name = None
        self._instance_id = None
        self._is_read_only = None
        self._is_shareable = None
        self._type = None
        self._volume_id = None
        self._type = 'service_determined'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
